@@ -1,18 +1,18 @@
 /*======================================================================
  FILE: regression-component.c
 
- (C) COPYRIGHT 1999 Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 1999 Eric Busboom <eric@civicknowledge.com>
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
 
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+
+ Or:
+
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
 
  The original author is Eric Busboom
 ======================================================================*/
@@ -47,7 +47,7 @@ void create_simple_component(void)
     icalcomponent_free(calendar);
 }
 
-static char *create_new_component_str =
+static const char *create_new_component_str =
     "BEGIN:VCALENDAR\r\n"
     "VERSION:2.0\r\n"
     "PRODID:-//RDU Software//NONSGML HandCal//EN\r\n"
@@ -89,14 +89,15 @@ void create_new_component()
     icalcomponent *timezone;
     icalcomponent *tzc;
     icalcomponent *event;
-    struct icaltimetype atime = icaltime_from_timet(1023398689, 0);
+    struct icaltimetype atime = icaltime_from_timet_with_zone(1023398689, 0, NULL);
     struct icaldatetimeperiodtype rtime;
     icalproperty *property;
     char *calendar_as_string;
 
-    rtime.period.start = icaltime_from_timet(1023398689, 0);
-    rtime.period.end = icaltime_from_timet(1023409689, 0);
+    rtime.period.start = icaltime_from_timet_with_zone(1023398689, 0, NULL);
+    rtime.period.end = icaltime_from_timet_with_zone(1023409689, 0, NULL);
     rtime.period.end.hour++;
+    rtime.period.duration = icaldurationtype_null_duration();
     rtime.time = icaltime_null_time();
 
     /* Create calendar and add properties */
@@ -215,12 +216,13 @@ void create_new_component()
 void create_new_component_with_va_args()
 {
     icalcomponent *calendar;
-    struct icaltimetype atime = icaltime_from_timet(time(0), 0);
+    struct icaltimetype atime = icaltime_from_timet_with_zone(time(0), 0, NULL);
     struct icaldatetimeperiodtype rtime;
 
-    rtime.period.start = icaltime_from_timet(time(0), 0);
-    rtime.period.end = icaltime_from_timet(time(0), 0);
+    rtime.period.start = icaltime_from_timet_with_zone(time(0), 0, NULL);
+    rtime.period.end = icaltime_from_timet_with_zone(time(0), 0, NULL);
     rtime.period.end.hour++;
+    rtime.period.duration = icaldurationtype_null_duration();
     rtime.time = icaltime_null_time();
 
     calendar =
@@ -323,6 +325,7 @@ void test_icalcomponent_get_span()
      */
     span.start = tm1;
     span.end = tm2;
+    span.is_busy = 0;
     if (VERBOSE)
         print_span(tnum++, span);
 
@@ -353,8 +356,8 @@ void test_icalcomponent_get_span()
      */
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
-            icalproperty_vanew_dtstart(icaltime_from_timet(tm1, 0), 0),
-            icalproperty_vanew_dtend(icaltime_from_timet(tm2, 0), 0),
+            icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, NULL), 0),
+            icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, NULL), 0),
             (void *)0);
 
     span = icalcomponent_get_span(c);
@@ -438,14 +441,14 @@ void test_icalcomponent_get_span()
      */
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
-            icalproperty_new_dtstart(icaltime_from_timet(tm1, 0)),
+            icalproperty_new_dtstart(icaltime_from_timet_with_zone(tm1, 0, NULL)),
             (void *)0);
 
     span = icalcomponent_get_span(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("null span", (int)span.start, 0);
+    int_is("start == end", (int)span.start, span.end);
     icalcomponent_free(c);
 
     /** test 7
@@ -453,8 +456,8 @@ void test_icalcomponent_get_span()
      */
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
-            icalproperty_new_dtstart(icaltime_from_timet(tm1, 1)),
-            icalproperty_new_dtend(icaltime_from_timet(tm1, 1)),
+            icalproperty_new_dtstart(icaltime_from_timet_with_zone(tm1, 1, NULL)),
+            icalproperty_new_dtend(icaltime_from_timet_with_zone(tm1, 1, NULL)),
             (void *)0);
 
     span = icalcomponent_get_span(c);
@@ -468,8 +471,9 @@ void test_icalcomponent_get_span()
      *  We specify start and end date
      */
     c = icalcomponent_vanew(ICAL_VEVENT_COMPONENT,
-                            icalproperty_new_dtstart(icaltime_from_timet(tm1, 1)),
-                            icalproperty_new_dtend(icaltime_from_timet(tm2, 1)), (void *)0);
+                            icalproperty_new_dtstart(icaltime_from_timet_with_zone(tm1, 1, NULL)),
+                            icalproperty_new_dtend(icaltime_from_timet_with_zone(tm2, 1, NULL)),
+                            (void *)0);
 
     span = icalcomponent_get_span(c);
     int_is("UTC #2", (int)span.start, 973296000);
@@ -482,7 +486,8 @@ void test_icalcomponent_get_span()
      *  We specify start date
      */
     c = icalcomponent_vanew(ICAL_VEVENT_COMPONENT,
-                            icalproperty_new_dtstart(icaltime_from_timet(tm1, 1)), (void *)0);
+                            icalproperty_new_dtstart(icaltime_from_timet_with_zone(tm1, 1, NULL)),
+                            (void *)0);
 
     span = icalcomponent_get_span(c);
     if (VERBOSE)
